;; Generated package description from poke.el  -*- no-byte-compile: t -*-
(define-package "poke" "2.1.0.20220405.164557" "Emacs meets GNU poke!" '((emacs "25")) :commit "4e5528bff6245eaf0b60d224b3de0edeadb2bed7" :authors '(("Jose E. Marchesi" . "jemarch@gnu.org")) :maintainer '("Jose E. Marchesi" . "jemarch@gnu.org") :url "https://www.jemarch.net/poke")
